Python_SI1145
=============

Python library for accessing the SI1145 temperature sensor on a Raspberry Pi.

Designed specifically to work with the Adafruit SI1145 sensors ----> https://www.adafruit.com/product/1777

To install, download the library by clicking the download zip link to the right and unzip the archive somewhere on your Raspberry Pi. Then execute the following command in the directory of the library:

sudo python setup.py install

Make sure you have internet access on the device so it can download the required dependencies.

See examples of usage in the examples folder.

Please support Adafruit (though I have no connection to them) and open-source hardware by purchasing products from Adafruit!

Written by Joe Gutting. MIT license, all text above must be included in any redistribution.

Credit to Adafruit for their Arduino SI1145 library as well as their Adafruit GPIO I2C library. Also to Tony Dicola for his BMP python library which I used as a template.
